==> emodpy_tbhiv-0.0.6-py3-none-any.whl: tests/test_smeardiag.py <==
#!/usr/bin/env python
import unittest
import copy
import json
import os
import manifest
from intervention_test import TestIntervention

import emodpy_tbhiv.interventions.smear_diag as sd
import emod_api.campaign as camp


class Testsmeardiag(TestIntervention):
    """
    Test SmearDiagnostic intervention
    """
    def test_default(self):
        super().trigger_treatment_list_test(sd.SmearDiagnostic, "SmearDiagnostic", "camp_smeardiag.json")

    def test_all(self):
        camp.schema_path = self.schema
        trigger_treatment_list = ['infected']
        base_sensitivity_smearpos = 0.2
        base_sensitivity_smearneg = 0.3
        pos_event = 'TestPositiveOnSmear'
        treatment_fraction = 0.4
        start_day = 2
        duration = 1
        property_restrictions_list = ['Demo: 8']
        expected_property_restrictions_list = copy.deepcopy(property_restrictions_list)
        nodeIDs = []
        black_period = 0
        black_trigger = 'Blackout'
        event_name = 'TB Diagnosis Smear Simple'
        event = sd.SmearDiagnostic(camp, trigger_treatment_list, base_sensitivity_smearpos, base_sensitivity_smearneg,
                                   pos_event, treatment_fraction, start_day, duration, property_restrictions_list,
                                   nodeIDs, black_period, black_trigger, event_name)
        camp.add(event, first=True)
        camp_filename = os.path.join(self.output, "camp_smeardiag.json")
        manifest.delete_existing_file(camp_filename)
        camp.save(camp_filename)
        self.assertTrue(os.path.isfile(camp_filename))

        with open(camp_filename, 'r') as file:
            camp_file = json.load(file)
        ecc = camp_file["Events"][0]["Event_Coordinator_Config"]
        ic = ecc["Intervention_Config"]
        intervention = ic["Actual_IndividualIntervention_Config"]

        self.assertEqual(intervention["Base_Sensitivity"], base_sensitivity_smearpos)
        self.assertEqual(intervention["Base_Specificity"], base_sensitivity_smearneg)
        self.assertEqual(intervention["Event_Or_Config"], "Event")
        self.assertEqual(intervention["Positive_Diagnosis_Event"], pos_event)
        self.assertEqual(intervention["Treatment_Fraction"], treatment_fraction)

        self.assertEqual(ic["Property_Restrictions"], expected_property_restrictions_list)
        self.assertEqual(ic["Duration"], duration)
        self.assertEqual(ic["Blackout_Period"], black_period)
        self.assertEqual(ic["Blackout_Event_Trigger"], black_trigger)
        self.assertEqual(camp_file["Events"][0]["Start_Day"], start_day)
        self.assertEqual(camp.pubsub_signals_pubbing, [pos_event])


if __name__ == '__main__':
    unittest.main()

==> emodpy_tbhiv-0.0.13-py3-none-any.whl: tests/test_smeardiag.py <==
#!/usr/bin/env python
import unittest
import copy
import json
import os
import manifest
from intervention_test import TestIntervention

import emodpy_tbhiv.interventions.smear_diag as sd
import emod_api.campaign as camp


class Testsmeardiag(TestIntervention):
    """
    Test SmearDiagnostic intervention
    """
    def test_default(self):
        super().trigger_treatment_list_test(sd.SmearDiagnostic, "SmearDiagnostic", "camp_smeardiag.json")

    def test_all(self):
        camp.schema_path = self.schema
        trigger_treatment_list = ['infected']
        base_sensitivity_smearpos = 0.2
        base_sensitivity_smearneg = 0.3
        pos_event = 'TestPositiveOnSmear'
        treatment_fraction = 0.4
        start_day = 2
        duration = 1
        property_restrictions_list = ['Demo: 8']
        expected_property_restrictions_list = copy.deepcopy(property_restrictions_list)
        nodeIDs = []
        black_period = 0
        black_trigger = 'Blackout'
        event_name = 'TB Diagnosis Smear Simple'
        event = sd.SmearDiagnostic(camp, trigger_treatment_list, base_sensitivity_smearpos, base_sensitivity_smearneg,
                                   pos_event, treatment_fraction, start_day, duration, property_restrictions_list,
                                   nodeIDs, black_period, black_trigger, event_name)
        camp.add(event, first=True)
        camp_filename = os.path.join(self.output, "camp_smeardiag.json")
        manifest.delete_existing_file(camp_filename)
        camp.save(camp_filename)
        self.assertTrue(os.path.isfile(camp_filename))

        with open(camp_filename, 'r') as file:
            camp_file = json.load(file)
        ecc = camp_file["Events"][0]["Event_Coordinator_Config"]
        ic = ecc["Intervention_Config"]
        intervention = ic["Actual_IndividualIntervention_Config"]["Intervention_List"][0]

        self.assertEqual(intervention["Base_Sensitivity"], base_sensitivity_smearpos)
        self.assertEqual(intervention["Base_Specificity"], base_sensitivity_smearneg)
        self.assertEqual(intervention["Event_Or_Config"], "Event")
        self.assertEqual(intervention["Positive_Diagnosis_Event"], pos_event)
        self.assertEqual(intervention["Treatment_Fraction"], treatment_fraction)

        self.assertListEqual(ic["Property_Restrictions"], [property_restrictions.replace(" ", "") for
                                                           property_restrictions in expected_property_restrictions_list])
        self.assertEqual(ic["Duration"], duration)
        # self.assertEqual(ic["Blackout_Period"], black_period)
        # self.assertEqual(ic["Blackout_Event_Trigger"], black_trigger)
        self.assertEqual(camp_file["Events"][0]["Start_Day"], start_day)
        self.assertEqual(camp.pubsub_signals_pubbing, [pos_event])

    def test_new_intervention_as_file(self, intervention_class_name='SmearDiagnostic'):
        camp_filename = os.path.join(self.output, 'camp_smeardiag_as_file.json')
        super().new_intervention_as_file_test(sd, camp_filename, intervention_class_name, is_multi=True)


if __name__ == '__main__':
    unittest.main()
